@@ -25,7 +25,8 @@ def write():
             file.write("influenza/A good rest is all you need,and drink more water.\ncommon cold/Please drink more hot water,and wear more warm clothes.\nphysical fitness/Please drink more hot water to prevent cold.\nrun a fever/Please go to the hospital for treatment.")
             file.close()
 
-        except:
+        except Exception as e:
+            print(e)
             print('Something went wrong! Cannot tell what?')
             sys.exit(0) # quit Python
 def get_name():
